window.Gleam.initSearch([{"doc":"gleam_synapses","title":"gleam_synapses","content":"# gleam_synapses\n\nA plug-and-play library for **neural networks** written in **Gleam**!\n\n## Basic usage\n\n### Install synapses\n\nRun `gleam add gleam_synapses` in the directory of your project.\n\n### Import the `Net` module\n\n```gleam\nimport gleam_synapses/net.{type Net}\n```\n\n### Create a random neural network by providing its layer sizes\n\n```gleam\nlet rand_net = net.new([2, 3, 1])\n```\n\n* Input layer: the first layer of the network has 2 nodes.\n* Hidden layer: the second layer has 3 neurons.\n* Output layer: the third layer has 1 neuron.\n\n### Get the json of the random neural network\n\n```gleam\nnet.to_json(rand_net)\n// &quot;[\n//   [{\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [-0.5,0.1,0.8]},\n//    {\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [0.7,0.6,-0.1]},\n//    {\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [-0.8,-0.1,-0.7]}],\n//   [{\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [0.5,-0.3,-0.4,-0.5]}]\n// ]&quot;\n```\n\n\n### Create a neural network by providing its json\n\n```gleam\nlet network = net.from_json(&quot;[\n   [{\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [-0.5,0.1,0.8]},\n    {\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [0.7,0.6,-0.1]},\n    {\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [-0.8,-0.1,-0.7]}],\n   [{\\&quot;activationF\\&quot; : \\&quot;sigmoid\\&quot;, \\&quot;weights\\&quot; : [0.5,-0.3,-0.4,-0.5]}]\n ]&quot;)\n```\n\n### Make a prediction\n\n```gleam\nnet.predict(network, [0.2, 0.6])\n// [0.49131100324012494]\n```\n\n### Train a neural network\n\n```gleam\nnet.fit(network, 0.1, [0.2, 0.6], [0.9])\n```\n\nThe `fit` method returns the neural network with its weights adjusted to a single observation.\n\n## Advanced usage\n\n### Fully train a neural network\n\nIn practice, for a neural network to be fully trained, it should be fitted with multiple observations, usually by folding over an iterator.\n\n```gleam\n[#([0.2, 0.6], [0.9]),\n #([0.1, 0.8], [0.2]),\n #([0.5, 0.4], [0.6])]\n|&gt; iterator.from_list\n|&gt; iterator.fold(network, fn(acc, t) {\n  let #(xs, ys) = t\n  net.fit(acc, 0.1, xs, ys)\n})\n```\n\n### Boost the performance\n\nEvery function is efficient because its implementation is based on lazy list\nand all information is obtained at a single pass.\n\nFor a neural network that has huge layers, the performance can be further improved\nby using the parallel counterparts of `predict` and `fit` (`par_predict` and `par_fit`).\n\n### Create a neural network for testing\n\n```gleam\nnet.new_with_seed([2, 3, 1], 1000)\n```\n\nWe can provide a `seed` to create a non-random neural network.\nThis way, we can use it for testing.\n\n### Define the activation functions and the weights\n\n```gleam\nimport gleam_synapses/fun.{type Fun}\nimport gleam/float\n\nlet activation_f = fn(layer_index: Int) -&gt; Fun {\n  case layer_index {\n    0 -&gt; fun.sigmoid()\n    1 -&gt; fun.identity()\n    2 -&gt; fun.leaky_re_lu()\n    3 -&gt; fun.tanh()\n  }\n}\n\nlet weight_init_f = fn(_: Int) -&gt; Float {\n  float.random(0.0, 1.0)\n}\n\nlet custom_net = net.new_custom([4, 6, 8, 5, 3], activation_f, weight_init_f)\n```\n\n* The `activation_f` function accepts the index of a layer and returns an activation function for its neurons.\n* The `weight_init_f` function accepts the index of a layer and returns a weight for the synapses of its neurons.\n\nIf we don&#39;t provide these functions, the activation function of all neurons is sigmoid,\nand the weight distribution of the synapses is normal between -1.0 and 1.0.\n\n### Draw a neural network\n\n```gleam\nnet.to_svg(custom_net)\n```\n\n![Network Drawing](https://github.com/mrdimosthenis/gleam_synapses/blob/master/readme_resources/network-drawing.png?raw=true)\n\nWith its svg drawing, we can see what a neural network looks like.\nThe color of each neuron depends on its activation function\nwhile the transparency of the synapses depends on their weight.\n\n### Measure the difference between the expected and predicted values\n\n```gleam\nimport gleam_synapses/stats\n\nfn exp_and_pred_vals() -&gt; Iterator(#(List(Float), List(Float))) {\n  [\n    #([0.0, 0.0, 1.0], [0.0, 0.1, 0.9]),\n    #([0.0, 1.0, 0.0], [0.8, 0.2, 0.0]),\n    #([1.0, 0.0, 0.0], [0.7, 0.1, 0.2]),\n    #([1.0, 0.0, 0.0], [0.3, 0.3, 0.4]),\n    #([0.0, 0.0, 1.0], [0.2, 0.2, 0.6])\n  ]\n  |&gt; iterator.from_list\n}\n```\n\n* Root-mean-square error\n\n```gleam\nstats.rmse(exp_and_pred_vals())\n// 0.6957010852370435\n```\n\n* Classification accuracy score\n\n```gleam\nstats.score(exp_and_pred_vals())\n// 0.6\n```\n\n### Import the `Codec` module\n\n```gleam\nimport gleam_synapses/codec.{type Codec}\n```\n\n* One hot encoding is a process that turns discrete attributes into a list of 0.0 and 1.0.\n* Minmax normalization scales continuous attributes into values between 0.0 and 1.0.\n\n```gleam\nfn setosa() -&gt; Dict(String, String) {\n  [\n    #(&quot;petal_length&quot;, &quot;1.5&quot;),\n    #(&quot;petal_width&quot;, &quot;0.1&quot;),\n    #(&quot;sepal_length&quot;, &quot;4.9&quot;),\n    #(&quot;sepal_width&quot;, &quot;3.1&quot;),\n    #(&quot;species&quot;, &quot;setosa&quot;)\n  ]\n  |&gt; dict.from_list\n}\n\nfn versicolor() -&gt; Dict(String, String) {\n  [\n    #(&quot;petal_length&quot;, &quot;3.8&quot;),\n    #(&quot;petal_width&quot;, &quot;1.1&quot;),\n    #(&quot;sepal_length&quot;, &quot;5.5&quot;),\n    #(&quot;sepal_width&quot;, &quot;2.4&quot;),\n    #(&quot;species&quot;, &quot;versicolor&quot;)\n  ]\n  |&gt; dict.from_list\n}\n\nfn virginica() -&gt; Dict(String, String) {\n  [\n    #(&quot;petal_length&quot;, &quot;6.0&quot;),\n    #(&quot;petal_width&quot;, &quot;2.2&quot;),\n    #(&quot;sepal_length&quot;, &quot;5.0&quot;),\n    #(&quot;sepal_width&quot;, &quot;1.5&quot;),\n    #(&quot;species&quot;, &quot;virginica&quot;)\n  ]\n  |&gt; dict.from_list\n}\n\nfn dataset() -&gt; Iterator(Dict(String, String)) {\n  iterator.from_list([setosa(), versicolor(), virginica()])\n}\n```\n\nYou can use a `Codec` to encode and decode a data point.\n\n### Create a `Codec` by providing the attributes and the data points\n\n```gleam\nlet cdc = codec.new([\n      #(&quot;petal_length&quot;, False),\n      #(&quot;petal_width&quot;, False),\n      #(&quot;sepal_length&quot;, False),\n      #(&quot;sepal_width&quot;, False),\n      #(&quot;species&quot;, True))\n    ],\n    dataset()\n)\n```\n\n* The first parameter is a list of pairs that define the name and the type (discrete or not) of each attribute.\n* The second parameter is an iterator that contains the data points.\n\n### Get the json of the codec\n\n```gleam\nlet codec_json = codec.to_json(cdc)\n// &quot;[\n//   {\\&quot;Case\\&quot; : \\&quot;SerializableContinuous\\&quot;,\n//    \\&quot;Fields\\&quot; : [{\\&quot;key\\&quot; : \\&quot;petal_length\\&quot;,\\&quot;min\\&quot; : 1.5,\\&quot;max\\&quot; : 6.0}]},\n//   {\\&quot;Case\\&quot; : \\&quot;SerializableContinuous\\&quot;,\n//    \\&quot;Fields\\&quot; : [{\\&quot;key\\&quot; : \\&quot;petal_width\\&quot;,\\&quot;min\\&quot; : 0.1,\\&quot;max\\&quot; : 2.2}]},\n//   {\\&quot;Case\\&quot; : \\&quot;SerializableContinuous\\&quot;,\n//    \\&quot;Fields\\&quot; : [{\\&quot;key\\&quot; : \\&quot;sepal_length\\&quot;,\\&quot;min\\&quot; : 4.9,\\&quot;max\\&quot; : 5.5}]},\n//   {\\&quot;Case\\&quot; : \\&quot;SerializableContinuous\\&quot;,\n//    \\&quot;Fields\\&quot; : [{\\&quot;key\\&quot; : \\&quot;sepal_width\\&quot;,\\&quot;min\\&quot; : 1.5,\\&quot;max\\&quot; : 3.1}]},\n//   {\\&quot;Case\\&quot; : \\&quot;SerializableDiscrete\\&quot;,\n//    \\&quot;Fields\\&quot; : [{\\&quot;key\\&quot; : \\&quot;species\\&quot;,\\&quot;values\\&quot; : [\\&quot;virginica\\&quot;,\\&quot;versicolor\\&quot;,\\&quot;setosa\\&quot;]}]}\n// ]&quot;\n```\n\n\n### Create a codec by providing its json\n\n```gleam\ncodec.from_json(codec_json)\n```\n\n### Encode a data point\n\n```gleam\nlet encoded_setosa = codec.encode(cdc, setosa())\n// [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 1.0]\n```\n\n### Decode a data point\n\n```gleam\ncodec.decode(cdc, encoded_setosa)\n|&gt; dict.to_list\n// [\n//   #(&quot;species&quot;, &quot;setosa&quot;),\n//   #(&quot;sepal_width&quot;, &quot;3.1&quot;),\n//   #(&quot;petal_width&quot;, &quot;0.1&quot;),\n//   #(&quot;petal_length&quot;, &quot;1.5&quot;),\n//   #(&quot;sepal_length&quot;, &quot;4.9&quot;)\n// ]\n```\n","url":"index.html"},{"doc":"gleam_synapses/model/encoding/attribute/attribute","title":"Attribute","content":"pub type Attribute {\n  Discrete(key: String, values: ZList(String))\n  Continuous(key: String, min: Float, max: Float)\n}\n\nDiscrete(key: String, values: ZList(String))\n\n\nContinuous(key: String, min: Float, max: Float)\n\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute.Attribute\ngleam_synapses/model/encoding/attribute/attribute Attribute","url":"gleam_synapses/model/encoding/attribute/attribute.html#Attribute"},{"doc":"gleam_synapses/model/encoding/attribute/attribute","title":"decode","content":"pub fn decode(\n  attribute: Attribute,\n  encoded_values: ZList(Float),\n) -&gt; String\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute.decode\ngleam_synapses/model/encoding/attribute/attribute decode","url":"gleam_synapses/model/encoding/attribute/attribute.html#decode"},{"doc":"gleam_synapses/model/encoding/attribute/attribute","title":"encode","content":"pub fn encode(\n  attribute: Attribute,\n  value: String,\n) -&gt; ZList(Float)\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute.encode\ngleam_synapses/model/encoding/attribute/attribute encode","url":"gleam_synapses/model/encoding/attribute/attribute.html#encode"},{"doc":"gleam_synapses/model/encoding/attribute/attribute","title":"parse","content":"pub fn parse(s: String) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute.parse\ngleam_synapses/model/encoding/attribute/attribute parse","url":"gleam_synapses/model/encoding/attribute/attribute.html#parse"},{"doc":"gleam_synapses/model/encoding/attribute/attribute","title":"updated","content":"pub fn updated(\n  attribute: Attribute,\n  datapoint: Dict(String, String),\n) -&gt; Attribute\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute.updated\ngleam_synapses/model/encoding/attribute/attribute updated","url":"gleam_synapses/model/encoding/attribute/attribute.html#updated"},{"doc":"gleam_synapses/model/encoding/attribute/attribute","title":"gleam_synapses/model/encoding/attribute/attribute","content":"","url":"gleam_synapses/model/encoding/attribute/attribute.html"},{"doc":"gleam_synapses/model/encoding/attribute/attribute_serialized","title":"decoder","content":"pub fn decoder() -&gt; fn(Dynamic) -&gt;\n  Result(Attribute, List(DecodeError))\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute_serialized.decoder\ngleam_synapses/model/encoding/attribute/attribute_serialized decoder","url":"gleam_synapses/model/encoding/attribute/attribute_serialized.html#decoder"},{"doc":"gleam_synapses/model/encoding/attribute/attribute_serialized","title":"realized","content":"pub fn realized(attr: Attribute) -&gt; Attribute\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute_serialized.realized\ngleam_synapses/model/encoding/attribute/attribute_serialized realized","url":"gleam_synapses/model/encoding/attribute/attribute_serialized.html#realized"},{"doc":"gleam_synapses/model/encoding/attribute/attribute_serialized","title":"serialized","content":"pub fn serialized(attr: Attribute) -&gt; Json\n\nSynonyms:\ngleam_synapses/model/encoding/attribute/attribute_serialized.serialized\ngleam_synapses/model/encoding/attribute/attribute_serialized serialized","url":"gleam_synapses/model/encoding/attribute/attribute_serialized.html#serialized"},{"doc":"gleam_synapses/model/encoding/attribute/attribute_serialized","title":"gleam_synapses/model/encoding/attribute/attribute_serialized","content":"","url":"gleam_synapses/model/encoding/attribute/attribute_serialized.html"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"Preprocessor","content":"pub type Preprocessor =\n  ZList(Attribute)\n\n\nSynonyms:\ngleam_synapses/model/encoding/preprocessor.Preprocessor\ngleam_synapses/model/encoding/preprocessor Preprocessor","url":"gleam_synapses/model/encoding/preprocessor.html#Preprocessor"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"decode","content":"pub fn decode(\n  preprocessor: ZList(Attribute),\n  encoded_datapoint: ZList(Float),\n) -&gt; Dict(String, String)\n\nSynonyms:\ngleam_synapses/model/encoding/preprocessor.decode\ngleam_synapses/model/encoding/preprocessor decode","url":"gleam_synapses/model/encoding/preprocessor.html#decode"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"encode","content":"pub fn encode(\n  preprocessor: ZList(Attribute),\n  datapoint: Dict(String, String),\n) -&gt; ZList(Float)\n\nSynonyms:\ngleam_synapses/model/encoding/preprocessor.encode\ngleam_synapses/model/encoding/preprocessor encode","url":"gleam_synapses/model/encoding/preprocessor.html#encode"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"init","content":"pub fn init(\n  keys_with_flags: ZList(#(String, Bool)),\n  dataset: Iterator(Dict(String, String)),\n) -&gt; ZList(Attribute)\n\nSynonyms:\ngleam_synapses/model/encoding/preprocessor.init\ngleam_synapses/model/encoding/preprocessor init","url":"gleam_synapses/model/encoding/preprocessor.html#init"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"of_json","content":"pub fn of_json(s: String) -&gt; ZList(Attribute)\n\nSynonyms:\ngleam_synapses/model/encoding/preprocessor.of_json\ngleam_synapses/model/encoding/preprocessor of_json","url":"gleam_synapses/model/encoding/preprocessor.html#of_json"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"realized","content":"pub fn realized(\n  preprocessor: ZList(Attribute),\n) -&gt; ZList(Attribute)\n\nSynonyms:\ngleam_synapses/model/encoding/preprocessor.realized\ngleam_synapses/model/encoding/preprocessor realized","url":"gleam_synapses/model/encoding/preprocessor.html#realized"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"to_json","content":"pub fn to_json(preprocessor: ZList(Attribute)) -&gt; String\n\nSynonyms:\ngleam_synapses/model/encoding/preprocessor.to_json\ngleam_synapses/model/encoding/preprocessor to_json","url":"gleam_synapses/model/encoding/preprocessor.html#to_json"},{"doc":"gleam_synapses/model/encoding/preprocessor","title":"gleam_synapses/model/encoding/preprocessor","content":"","url":"gleam_synapses/model/encoding/preprocessor.html"},{"doc":"gleam_synapses/codec","title":"Codec","content":"pub type Codec =\n  preprocessor.Preprocessor\n A codec can encode and decode every data point.\n\n\nSynonyms:\ngleam_synapses/codec.Codec\ngleam_synapses/codec Codec","url":"gleam_synapses/codec.html#Codec"},{"doc":"gleam_synapses/codec","title":"decode","content":"pub fn decode(\n  codec: ZList(Attribute),\n  encoded_values: List(Float),\n) -&gt; Dict(String, String)\n Accepts the `encoded_values` as a list of numbers between 0.0 and 1.0\n and returns the decoded data point as a map of strings.\n\n \n cdc\n |&gt; codec.decode([0.0, 1.0, 0.0])\n |&gt; dict.to_list\n [#(&quot;petal_length&quot;, &quot;1.5&quot;), #(&quot;species&quot;,&quot;setosa&quot;)]\n \n\nSynonyms:\ngleam_synapses/codec.decode\ngleam_synapses/codec decode","url":"gleam_synapses/codec.html#decode"},{"doc":"gleam_synapses/codec","title":"encode","content":"pub fn encode(\n  codec: ZList(Attribute),\n  data_point: Dict(String, String),\n) -&gt; List(Float)\n Accepts the `data_point` as a map of strings and returns the encoded data point\n as a list of float numbers between 0.0 and 1.0.\n\n \n codec.encode(cdc, setosa)\n [0.0, 1.0, 0.0]\n \n\nSynonyms:\ngleam_synapses/codec.encode\ngleam_synapses/codec encode","url":"gleam_synapses/codec.html#encode"},{"doc":"gleam_synapses/codec","title":"from_json","content":"pub fn from_json(json: String) -&gt; ZList(Attribute)\n Parses and returns a codec.\n\nSynonyms:\ngleam_synapses/codec.from_json\ngleam_synapses/codec from_json","url":"gleam_synapses/codec.html#from_json"},{"doc":"gleam_synapses/codec","title":"new","content":"pub fn new(\n  attributes: List(#(String, Bool)),\n  data_points: Iterator(Dict(String, String)),\n) -&gt; ZList(Attribute)\n Creates a codec that can encode and decode every data point.\n `attributes` is a list of pairs that define the name and the type (discrete or not) of each attribute.\n\n \n let attributes = [#(&quot;petal_length&quot;, False), #(&quot;species&quot;, True)]\n let setosa = dict.from_list([#(&quot;petal_length&quot;, &quot;1.5&quot;), #(&quot;species&quot;,&quot;setosa&quot;)])\n let versicolor = dict.from_list([#(&quot;petal_length&quot;, &quot;3.8&quot;), #(&quot;species&quot;,&quot;versicolor&quot;)])\n let data_points = iterator.from_list([setosa, versicolor])\n let cdc = codec.new(attributes, data_points)\n \n\nSynonyms:\ngleam_synapses/codec.new\ngleam_synapses/codec new","url":"gleam_synapses/codec.html#new"},{"doc":"gleam_synapses/codec","title":"to_json","content":"pub fn to_json(codec: ZList(Attribute)) -&gt; String\n The JSON representation of the `codec`.\nSynonyms:\ngleam_synapses/codec.to_json\ngleam_synapses/codec to_json","url":"gleam_synapses/codec.html#to_json"},{"doc":"gleam_synapses/codec","title":"gleam_synapses/codec","content":" This namespace contains functions that are related to data-point encodeing and decoding.\n\n One hot encoding is a process that turns discrete attributes into a list of 0.0 and 1.0.\n Minmax normalization scales continuous attributes into values between 0.0 and 1.0.\n","url":"gleam_synapses/codec.html"},{"doc":"gleam_synapses/model/mathematics","title":"accuracy","content":"pub fn accuracy(\n  y_hats_with_ys: Iterator(#(ZList(Float), ZList(Float))),\n) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/mathematics.accuracy\ngleam_synapses/model/mathematics accuracy","url":"gleam_synapses/model/mathematics.html#accuracy"},{"doc":"gleam_synapses/model/mathematics","title":"dot_product","content":"pub fn dot_product(\n  left: ZList(Float),\n  right: ZList(Float),\n) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/mathematics.dot_product\ngleam_synapses/model/mathematics dot_product","url":"gleam_synapses/model/mathematics.html#dot_product"},{"doc":"gleam_synapses/model/mathematics","title":"exp","content":"pub fn exp(x: Float) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/mathematics.exp\ngleam_synapses/model/mathematics exp","url":"gleam_synapses/model/mathematics.html#exp"},{"doc":"gleam_synapses/model/mathematics","title":"log","content":"pub fn log(x: Float) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/mathematics.log\ngleam_synapses/model/mathematics log","url":"gleam_synapses/model/mathematics.html#log"},{"doc":"gleam_synapses/model/mathematics","title":"root_mean_square_error","content":"pub fn root_mean_square_error(\n  y_hats_with_ys: Iterator(#(ZList(Float), ZList(Float))),\n) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/mathematics.root_mean_square_error\ngleam_synapses/model/mathematics root_mean_square_error","url":"gleam_synapses/model/mathematics.html#root_mean_square_error"},{"doc":"gleam_synapses/model/mathematics","title":"tanh","content":"pub fn tanh(x: Float) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/mathematics.tanh\ngleam_synapses/model/mathematics tanh","url":"gleam_synapses/model/mathematics.html#tanh"},{"doc":"gleam_synapses/model/mathematics","title":"gleam_synapses/model/mathematics","content":"","url":"gleam_synapses/model/mathematics.html"},{"doc":"gleam_synapses/model/net_elems/activation/activation","title":"Activation","content":"pub type Activation {\n  Sigmoid\n  Identity\n  Tanh\n  LeakyReLU\n}\n\nSigmoid\n\n\nIdentity\n\n\nTanh\n\n\nLeakyReLU\n\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation.Activation\ngleam_synapses/model/net_elems/activation/activation Activation","url":"gleam_synapses/model/net_elems/activation/activation.html#Activation"},{"doc":"gleam_synapses/model/net_elems/activation/activation","title":"deriv","content":"pub fn deriv(activation: Activation) -&gt; fn(Float) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation.deriv\ngleam_synapses/model/net_elems/activation/activation deriv","url":"gleam_synapses/model/net_elems/activation/activation.html#deriv"},{"doc":"gleam_synapses/model/net_elems/activation/activation","title":"f","content":"pub fn f(activation: Activation) -&gt; fn(Float) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation.f\ngleam_synapses/model/net_elems/activation/activation f","url":"gleam_synapses/model/net_elems/activation/activation.html#f"},{"doc":"gleam_synapses/model/net_elems/activation/activation","title":"generator","content":"pub fn generator() -&gt; Generator(Activation)\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation.generator\ngleam_synapses/model/net_elems/activation/activation generator","url":"gleam_synapses/model/net_elems/activation/activation.html#generator"},{"doc":"gleam_synapses/model/net_elems/activation/activation","title":"inverse","content":"pub fn inverse(activation: Activation) -&gt; fn(Float) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation.inverse\ngleam_synapses/model/net_elems/activation/activation inverse","url":"gleam_synapses/model/net_elems/activation/activation.html#inverse"},{"doc":"gleam_synapses/model/net_elems/activation/activation","title":"gleam_synapses/model/net_elems/activation/activation","content":"","url":"gleam_synapses/model/net_elems/activation/activation.html"},{"doc":"gleam_synapses/fun","title":"Fun","content":"pub type Fun =\n  activation.Activation\n The activation function a neuron can have.\n It can be used in the arguments of neural network&#39;s creation.\n\nSynonyms:\ngleam_synapses/fun.Fun\ngleam_synapses/fun Fun","url":"gleam_synapses/fun.html#Fun"},{"doc":"gleam_synapses/fun","title":"identity","content":"pub fn identity() -&gt; Activation\n Identity is a linear function where the output is equal to the input.\nSynonyms:\ngleam_synapses/fun.identity\ngleam_synapses/fun identity","url":"gleam_synapses/fun.html#identity"},{"doc":"gleam_synapses/fun","title":"leaky_re_lu","content":"pub fn leaky_re_lu() -&gt; Activation\n LeakyReLU gives a small proportion of x if x is negative and x otherwise.\nSynonyms:\ngleam_synapses/fun.leaky_re_lu\ngleam_synapses/fun leaky_re_lu","url":"gleam_synapses/fun.html#leaky_re_lu"},{"doc":"gleam_synapses/fun","title":"sigmoid","content":"pub fn sigmoid() -&gt; Activation\n Sigmoid takes any value as input and outputs values in the range of 0.0 to 1.0.\nSynonyms:\ngleam_synapses/fun.sigmoid\ngleam_synapses/fun sigmoid","url":"gleam_synapses/fun.html#sigmoid"},{"doc":"gleam_synapses/fun","title":"tanh","content":"pub fn tanh() -&gt; Activation\n Tanh is similar to sigmoid, but outputs values in the range of -1.0 and 1.0.\nSynonyms:\ngleam_synapses/fun.tanh\ngleam_synapses/fun tanh","url":"gleam_synapses/fun.html#tanh"},{"doc":"gleam_synapses/fun","title":"gleam_synapses/fun","content":"","url":"gleam_synapses/fun.html"},{"doc":"gleam_synapses/model/net_elems/activation/activation_serialized","title":"ActivationSerialized","content":"pub type ActivationSerialized =\n  String\n\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation_serialized.ActivationSerialized\ngleam_synapses/model/net_elems/activation/activation_serialized ActivationSerialized","url":"gleam_synapses/model/net_elems/activation/activation_serialized.html#ActivationSerialized"},{"doc":"gleam_synapses/model/net_elems/activation/activation_serialized","title":"deserialized","content":"pub fn deserialized(activation_serialized: String) -&gt; Activation\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation_serialized.deserialized\ngleam_synapses/model/net_elems/activation/activation_serialized deserialized","url":"gleam_synapses/model/net_elems/activation/activation_serialized.html#deserialized"},{"doc":"gleam_synapses/model/net_elems/activation/activation_serialized","title":"json_decoder","content":"pub fn json_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(String, List(DecodeError))\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation_serialized.json_decoder\ngleam_synapses/model/net_elems/activation/activation_serialized json_decoder","url":"gleam_synapses/model/net_elems/activation/activation_serialized.html#json_decoder"},{"doc":"gleam_synapses/model/net_elems/activation/activation_serialized","title":"json_encoded","content":"pub fn json_encoded(activation_serialised: String) -&gt; Json\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation_serialized.json_encoded\ngleam_synapses/model/net_elems/activation/activation_serialized json_encoded","url":"gleam_synapses/model/net_elems/activation/activation_serialized.html#json_encoded"},{"doc":"gleam_synapses/model/net_elems/activation/activation_serialized","title":"serialized","content":"pub fn serialized(activation: Activation) -&gt; String\n\nSynonyms:\ngleam_synapses/model/net_elems/activation/activation_serialized.serialized\ngleam_synapses/model/net_elems/activation/activation_serialized serialized","url":"gleam_synapses/model/net_elems/activation/activation_serialized.html#serialized"},{"doc":"gleam_synapses/model/net_elems/activation/activation_serialized","title":"gleam_synapses/model/net_elems/activation/activation_serialized","content":"","url":"gleam_synapses/model/net_elems/activation/activation_serialized.html"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron","title":"Neuron","content":"pub type Neuron {\n  Neuron(activation_f: Activation, weights: ZList(Float))\n}\n\nNeuron(activation_f: Activation, weights: ZList(Float))\n\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron.Neuron\ngleam_synapses/model/net_elems/neuron/neuron Neuron","url":"gleam_synapses/model/net_elems/neuron/neuron.html#Neuron"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron","title":"back_propagated","content":"pub fn back_propagated(\n  neuron: Neuron,\n  learning_rate: Float,\n  input_val: ZList(Float),\n  output_with_error: #(Float, Float),\n) -&gt; #(ZList(Float), Neuron)\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron.back_propagated\ngleam_synapses/model/net_elems/neuron/neuron back_propagated","url":"gleam_synapses/model/net_elems/neuron/neuron.html#back_propagated"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron","title":"generator","content":"pub fn generator(input_size: Int) -&gt; Generator(Neuron)\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron.generator\ngleam_synapses/model/net_elems/neuron/neuron generator","url":"gleam_synapses/model/net_elems/neuron/neuron.html#generator"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron","title":"init","content":"pub fn init(\n  input_size: Int,\n  activation_f: Activation,\n  weight_init_f: fn() -&gt; Float,\n) -&gt; Neuron\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron.init\ngleam_synapses/model/net_elems/neuron/neuron init","url":"gleam_synapses/model/net_elems/neuron/neuron.html#init"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron","title":"output","content":"pub fn output(neuron: Neuron, input_val: ZList(Float)) -&gt; Float\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron.output\ngleam_synapses/model/net_elems/neuron/neuron output","url":"gleam_synapses/model/net_elems/neuron/neuron.html#output"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron","title":"gleam_synapses/model/net_elems/neuron/neuron","content":"","url":"gleam_synapses/model/net_elems/neuron/neuron.html"},{"doc":"gleam_synapses/model/net_elems/layer/layer","title":"Layer","content":"pub type Layer =\n  ZList(Neuron)\n\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer.Layer\ngleam_synapses/model/net_elems/layer/layer Layer","url":"gleam_synapses/model/net_elems/layer/layer.html#Layer"},{"doc":"gleam_synapses/model/net_elems/layer/layer","title":"back_propagated","content":"pub fn back_propagated(\n  layer: ZList(Neuron),\n  learning_rate: Float,\n  input_val: ZList(Float),\n  output_with_error: ZList(#(Float, Float)),\n  in_parallel: Bool,\n) -&gt; #(ZList(Float), ZList(Neuron))\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer.back_propagated\ngleam_synapses/model/net_elems/layer/layer back_propagated","url":"gleam_synapses/model/net_elems/layer/layer.html#back_propagated"},{"doc":"gleam_synapses/model/net_elems/layer/layer","title":"generator","content":"pub fn generator(\n  input_size: Int,\n  output_size: Int,\n) -&gt; Generator(ZList(Neuron))\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer.generator\ngleam_synapses/model/net_elems/layer/layer generator","url":"gleam_synapses/model/net_elems/layer/layer.html#generator"},{"doc":"gleam_synapses/model/net_elems/layer/layer","title":"init","content":"pub fn init(\n  input_size: Int,\n  output_size: Int,\n  activation_f: Activation,\n  weight_init_f: fn() -&gt; fn() -&gt; Float,\n) -&gt; ZList(Neuron)\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer.init\ngleam_synapses/model/net_elems/layer/layer init","url":"gleam_synapses/model/net_elems/layer/layer.html#init"},{"doc":"gleam_synapses/model/net_elems/layer/layer","title":"output","content":"pub fn output(\n  layer: ZList(Neuron),\n  input_val: ZList(Float),\n  in_parallel: Bool,\n) -&gt; ZList(Float)\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer.output\ngleam_synapses/model/net_elems/layer/layer output","url":"gleam_synapses/model/net_elems/layer/layer.html#output"},{"doc":"gleam_synapses/model/net_elems/layer/layer","title":"gleam_synapses/model/net_elems/layer/layer","content":"","url":"gleam_synapses/model/net_elems/layer/layer.html"},{"doc":"gleam_synapses/model/net_elems/network/network","title":"Network","content":"pub type Network =\n  ZList(Layer)\n\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network.Network\ngleam_synapses/model/net_elems/network/network Network","url":"gleam_synapses/model/net_elems/network/network.html#Network"},{"doc":"gleam_synapses/model/net_elems/network/network","title":"errors","content":"pub fn errors(\n  network: ZList(ZList(Neuron)),\n  input_val: ZList(Float),\n  expected_output: ZList(Float),\n  in_parallel: Bool,\n) -&gt; ZList(Float)\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network.errors\ngleam_synapses/model/net_elems/network/network errors","url":"gleam_synapses/model/net_elems/network/network.html#errors"},{"doc":"gleam_synapses/model/net_elems/network/network","title":"fit","content":"pub fn fit(\n  network: ZList(ZList(Neuron)),\n  learning_rate: Float,\n  input_val: ZList(Float),\n  expected_output: ZList(Float),\n  in_parallel: Bool,\n) -&gt; ZList(ZList(Neuron))\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network.fit\ngleam_synapses/model/net_elems/network/network fit","url":"gleam_synapses/model/net_elems/network/network.html#fit"},{"doc":"gleam_synapses/model/net_elems/network/network","title":"generator","content":"pub fn generator(\n  layer_sizes: ZList(Int),\n) -&gt; Generator(ZList(ZList(Neuron)))\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network.generator\ngleam_synapses/model/net_elems/network/network generator","url":"gleam_synapses/model/net_elems/network/network.html#generator"},{"doc":"gleam_synapses/model/net_elems/network/network","title":"init","content":"pub fn init(\n  layer_sizes: ZList(Int),\n  activation_f: fn(Int) -&gt; Activation,\n  weight_init_f: fn(Int) -&gt; Float,\n) -&gt; ZList(ZList(Neuron))\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network.init\ngleam_synapses/model/net_elems/network/network init","url":"gleam_synapses/model/net_elems/network/network.html#init"},{"doc":"gleam_synapses/model/net_elems/network/network","title":"output","content":"pub fn output(\n  network: ZList(ZList(Neuron)),\n  input_val: ZList(Float),\n  in_parallel: Bool,\n) -&gt; ZList(Float)\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network.output\ngleam_synapses/model/net_elems/network/network output","url":"gleam_synapses/model/net_elems/network/network.html#output"},{"doc":"gleam_synapses/model/net_elems/network/network","title":"gleam_synapses/model/net_elems/network/network","content":"","url":"gleam_synapses/model/net_elems/network/network.html"},{"doc":"gleam_synapses/model/draw","title":"network_svg","content":"pub fn network_svg(network_val: ZList(ZList(Neuron))) -&gt; String\n\nSynonyms:\ngleam_synapses/model/draw.network_svg\ngleam_synapses/model/draw network_svg","url":"gleam_synapses/model/draw.html#network_svg"},{"doc":"gleam_synapses/model/draw","title":"gleam_synapses/model/draw","content":"","url":"gleam_synapses/model/draw.html"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron_serialized","title":"NeuronSerialized","content":"pub type NeuronSerialized {\n  NeuronSerialized(\n    activation_f: ActivationSerialized,\n    weights: List(Float),\n  )\n}\n\nNeuronSerialized(\n  activation_f: ActivationSerialized,\n  weights: List(Float),\n)\n\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron_serialized.NeuronSerialized\ngleam_synapses/model/net_elems/neuron/neuron_serialized NeuronSerialized","url":"gleam_synapses/model/net_elems/neuron/neuron_serialized.html#NeuronSerialized"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron_serialized","title":"deserialized","content":"pub fn deserialized(\n  neuron_serialized: NeuronSerialized,\n) -&gt; Neuron\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron_serialized.deserialized\ngleam_synapses/model/net_elems/neuron/neuron_serialized deserialized","url":"gleam_synapses/model/net_elems/neuron/neuron_serialized.html#deserialized"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron_serialized","title":"json_decoder","content":"pub fn json_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(NeuronSerialized, List(DecodeError))\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron_serialized.json_decoder\ngleam_synapses/model/net_elems/neuron/neuron_serialized json_decoder","url":"gleam_synapses/model/net_elems/neuron/neuron_serialized.html#json_decoder"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron_serialized","title":"json_encoded","content":"pub fn json_encoded(neuron_serialized: NeuronSerialized) -&gt; Json\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron_serialized.json_encoded\ngleam_synapses/model/net_elems/neuron/neuron_serialized json_encoded","url":"gleam_synapses/model/net_elems/neuron/neuron_serialized.html#json_encoded"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron_serialized","title":"serialized","content":"pub fn serialized(neuron: Neuron) -&gt; NeuronSerialized\n\nSynonyms:\ngleam_synapses/model/net_elems/neuron/neuron_serialized.serialized\ngleam_synapses/model/net_elems/neuron/neuron_serialized serialized","url":"gleam_synapses/model/net_elems/neuron/neuron_serialized.html#serialized"},{"doc":"gleam_synapses/model/net_elems/neuron/neuron_serialized","title":"gleam_synapses/model/net_elems/neuron/neuron_serialized","content":"","url":"gleam_synapses/model/net_elems/neuron/neuron_serialized.html"},{"doc":"gleam_synapses/model/net_elems/layer/layer_serialized","title":"LayerSerialized","content":"pub type LayerSerialized =\n  List(NeuronSerialized)\n\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer_serialized.LayerSerialized\ngleam_synapses/model/net_elems/layer/layer_serialized LayerSerialized","url":"gleam_synapses/model/net_elems/layer/layer_serialized.html#LayerSerialized"},{"doc":"gleam_synapses/model/net_elems/layer/layer_serialized","title":"deserialized","content":"pub fn deserialized(\n  layer_serialized: List(NeuronSerialized),\n) -&gt; ZList(Neuron)\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer_serialized.deserialized\ngleam_synapses/model/net_elems/layer/layer_serialized deserialized","url":"gleam_synapses/model/net_elems/layer/layer_serialized.html#deserialized"},{"doc":"gleam_synapses/model/net_elems/layer/layer_serialized","title":"json_decoder","content":"pub fn json_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(List(NeuronSerialized), List(DecodeError))\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer_serialized.json_decoder\ngleam_synapses/model/net_elems/layer/layer_serialized json_decoder","url":"gleam_synapses/model/net_elems/layer/layer_serialized.html#json_decoder"},{"doc":"gleam_synapses/model/net_elems/layer/layer_serialized","title":"json_encoded","content":"pub fn json_encoded(\n  layer_serialized: List(NeuronSerialized),\n) -&gt; Json\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer_serialized.json_encoded\ngleam_synapses/model/net_elems/layer/layer_serialized json_encoded","url":"gleam_synapses/model/net_elems/layer/layer_serialized.html#json_encoded"},{"doc":"gleam_synapses/model/net_elems/layer/layer_serialized","title":"serialized","content":"pub fn serialized(layer: ZList(Neuron)) -&gt; List(NeuronSerialized)\n\nSynonyms:\ngleam_synapses/model/net_elems/layer/layer_serialized.serialized\ngleam_synapses/model/net_elems/layer/layer_serialized serialized","url":"gleam_synapses/model/net_elems/layer/layer_serialized.html#serialized"},{"doc":"gleam_synapses/model/net_elems/layer/layer_serialized","title":"gleam_synapses/model/net_elems/layer/layer_serialized","content":"","url":"gleam_synapses/model/net_elems/layer/layer_serialized.html"},{"doc":"gleam_synapses/model/net_elems/network/network_serialized","title":"of_json","content":"pub fn of_json(s: String) -&gt; ZList(ZList(Neuron))\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network_serialized.of_json\ngleam_synapses/model/net_elems/network/network_serialized of_json","url":"gleam_synapses/model/net_elems/network/network_serialized.html#of_json"},{"doc":"gleam_synapses/model/net_elems/network/network_serialized","title":"realized","content":"pub fn realized(\n  network: ZList(ZList(Neuron)),\n) -&gt; ZList(ZList(Neuron))\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network_serialized.realized\ngleam_synapses/model/net_elems/network/network_serialized realized","url":"gleam_synapses/model/net_elems/network/network_serialized.html#realized"},{"doc":"gleam_synapses/model/net_elems/network/network_serialized","title":"serialized","content":"pub fn serialized(\n  network: ZList(ZList(Neuron)),\n) -&gt; List(List(NeuronSerialized))\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network_serialized.serialized\ngleam_synapses/model/net_elems/network/network_serialized serialized","url":"gleam_synapses/model/net_elems/network/network_serialized.html#serialized"},{"doc":"gleam_synapses/model/net_elems/network/network_serialized","title":"to_json","content":"pub fn to_json(network: ZList(ZList(Neuron))) -&gt; String\n\nSynonyms:\ngleam_synapses/model/net_elems/network/network_serialized.to_json\ngleam_synapses/model/net_elems/network/network_serialized to_json","url":"gleam_synapses/model/net_elems/network/network_serialized.html#to_json"},{"doc":"gleam_synapses/model/net_elems/network/network_serialized","title":"gleam_synapses/model/net_elems/network/network_serialized","content":"","url":"gleam_synapses/model/net_elems/network/network_serialized.html"},{"doc":"gleam_synapses/net","title":"Net","content":"pub type Net =\n  network.Network\n\n\nSynonyms:\ngleam_synapses/net.Net\ngleam_synapses/net Net","url":"gleam_synapses/net.html#Net"},{"doc":"gleam_synapses/net","title":"errors","content":"pub fn errors(\n  net: ZList(ZList(Neuron)),\n  input_values: List(Float),\n  expected_output: List(Float),\n  in_parallel: Bool,\n) -&gt; List(Float)\n\nSynonyms:\ngleam_synapses/net.errors\ngleam_synapses/net errors","url":"gleam_synapses/net.html#errors"},{"doc":"gleam_synapses/net","title":"fit","content":"pub fn fit(\n  net: ZList(ZList(Neuron)),\n  learning_rate: Float,\n  input_values: List(Float),\n  expected_output: List(Float),\n) -&gt; ZList(ZList(Neuron))\n Returns the neural network with its weights adjusted to the provided observation.\n\n `learning_rate` is a number that controls how much the weights are adjusted to the observation.\n `input_values` is the feature values of the observation and its size should be equal to the size of the input layer.\n `expected_output` is the expected output of the observation and its size should be equal to the size of the output layer.\n\n In order for a network to be fully trained, it should fit with multiple observations, usually by folding over an iterator.\n\nSynonyms:\ngleam_synapses/net.fit\ngleam_synapses/net fit","url":"gleam_synapses/net.html#fit"},{"doc":"gleam_synapses/net","title":"from_json","content":"pub fn from_json(json: String) -&gt; ZList(ZList(Neuron))\n Parses and returns a neural network.\n\n \n net.from_json(&quot;[[{\\&quot;activationF\\&quot;:\\&quot;sigmoid\\&quot;,\\&quot;weights\\&quot;:[-0.4,-0.1,-0.8]}]]&quot;)\n \n\nSynonyms:\ngleam_synapses/net.from_json\ngleam_synapses/net from_json","url":"gleam_synapses/net.html#from_json"},{"doc":"gleam_synapses/net","title":"new","content":"pub fn new(layers: List(Int)) -&gt; ZList(ZList(Neuron))\n Creates a random neural network by accepting its layer sizes.\n\n \n net.new([3, 4, 2])\n \n\nSynonyms:\ngleam_synapses/net.new\ngleam_synapses/net new","url":"gleam_synapses/net.html#new"},{"doc":"gleam_synapses/net","title":"new_custom","content":"pub fn new_custom(\n  layers: List(Int),\n  activation_f: fn(Int) -&gt; Activation,\n  weight_init_f: fn(Int) -&gt; Float,\n) -&gt; ZList(ZList(Neuron))\n Creates a neural network by accepting the size, the activation function and the weights for each layer.\n\n \n net.new_custom([3, 4, 2], fn(_){fun.sigmoid()}, fn(_){float.random(0.0, 1.0)})\n \n\nSynonyms:\ngleam_synapses/net.new_custom\ngleam_synapses/net new_custom","url":"gleam_synapses/net.html#new_custom"},{"doc":"gleam_synapses/net","title":"new_with_seed","content":"pub fn new_with_seed(\n  layers: List(Int),\n  seed: Int,\n) -&gt; ZList(ZList(Neuron))\n Creates a non-random neural network by accepting its layer sizes and a seed.\n `seed` is the number used to initialize the internal pseudorandom number generator.\n\n \n net.new([3, 4, 2], 1000)\n \n\nSynonyms:\ngleam_synapses/net.new_with_seed\ngleam_synapses/net new_with_seed","url":"gleam_synapses/net.html#new_with_seed"},{"doc":"gleam_synapses/net","title":"par_fit","content":"pub fn par_fit(\n  net: ZList(ZList(Neuron)),\n  learning_rate: Float,\n  input_values: List(Float),\n  expected_output: List(Float),\n) -&gt; ZList(ZList(Neuron))\n Returns the neural network with its weights adjusted to the provided observation.\n\n The calculation is performed in parallel.\n When the neural network has huge layers, the parallel calculation boosts the performance.\n\nSynonyms:\ngleam_synapses/net.par_fit\ngleam_synapses/net par_fit","url":"gleam_synapses/net.html#par_fit"},{"doc":"gleam_synapses/net","title":"par_predict","content":"pub fn par_predict(\n  net: ZList(ZList(Neuron)),\n  input_values: List(Float),\n) -&gt; List(Float)\n Calculates the prediction for the provided input in parallel.\n It&#39;s usefull for neural networks with huge layers.\n\nSynonyms:\ngleam_synapses/net.par_predict\ngleam_synapses/net par_predict","url":"gleam_synapses/net.html#par_predict"},{"doc":"gleam_synapses/net","title":"predict","content":"pub fn predict(\n  net: ZList(ZList(Neuron)),\n  input_values: List(Float),\n) -&gt; List(Float)\n Makes a prediction for the provided input.\n The size of the returned list should be equal to the size of the output layer.\n\n `input_values` should be the list that contains the values of the features.\n Its size should be equal to the size of the input layer.\n\nSynonyms:\ngleam_synapses/net.predict\ngleam_synapses/net predict","url":"gleam_synapses/net.html#predict"},{"doc":"gleam_synapses/net","title":"to_json","content":"pub fn to_json(net: ZList(ZList(Neuron))) -&gt; String\n The JSON representation of the neural network.\n\nSynonyms:\ngleam_synapses/net.to_json\ngleam_synapses/net to_json","url":"gleam_synapses/net.html#to_json"},{"doc":"gleam_synapses/net","title":"to_svg","content":"pub fn to_svg(net: ZList(ZList(Neuron))) -&gt; String\n Returns the SVG representation of the neural network.\n\n The color of each neuron depends on its activation function\n while the transparency of the synapses depends on their weight.\n\nSynonyms:\ngleam_synapses/net.to_svg\ngleam_synapses/net to_svg","url":"gleam_synapses/net.html#to_svg"},{"doc":"gleam_synapses/net","title":"gleam_synapses/net","content":" This namespace contains functions that are related to the neural networks.","url":"gleam_synapses/net.html"},{"doc":"gleam_synapses/stats","title":"rmse","content":"pub fn rmse(\n  output_pairs: Iterator(#(List(Float), List(Float))),\n) -&gt; Float\n The standard deviation of the prediction errors (root mean square error).\n `output_pairs` should be an iterator o tuples that contain the expected and predicted values.\n\n \n [#([0.0, 0.0, 1.0], [0.0, 0.0, 1.0]),\n  #([0.0, 0.0, 1.0], [0.0, 1.0, 1.0])]\n |&gt; iterator.from_list\n |&gt; stats.rmse\n 0.7071067811865476\n \n\nSynonyms:\ngleam_synapses/stats.rmse\ngleam_synapses/stats rmse","url":"gleam_synapses/stats.html#rmse"},{"doc":"gleam_synapses/stats","title":"score","content":"pub fn score(\n  output_pairs: Iterator(#(List(Float), List(Float))),\n) -&gt; Float\n The ratio of correct predictions to the total number of provided observations.\n For a prediction to be considered as correct, the index of its maximum expected value\n needs to be the same with the index of its maximum predicted value.\n `output_pairs` should be an iterator o tuples that contain the expected and predicted values.\n\n \n [\n   #([0.0, 0.0, 1.0], [0.0, 0.1, 0.9]),\n   #([0.0, 1.0, 0.0], [0.8, 0.2, 0.0]),\n   #([1.0, 0.0, 0.0], [0.7, 0.1, 0.2]),\n   #([1.0, 0.0, 0.0], [0.3, 0.3, 0.4]),\n   #([0.0, 0.0, 1.0], [0.2, 0.2, 0.6]),\n ]\n |&gt; iterator.from_list\n |&gt; stats.score\n 0.6\n \n\nSynonyms:\ngleam_synapses/stats.score\ngleam_synapses/stats score","url":"gleam_synapses/stats.html#score"},{"doc":"gleam_synapses/stats","title":"gleam_synapses/stats","content":" Measure the difference between the values predicted by a neural network and the observed values.","url":"gleam_synapses/stats.html"}]);